package com.webchat.user.service.relation;


import com.webchat.common.enums.RoleCodeEnum;
import com.webchat.common.exception.BusinessException;
import com.webchat.common.util.SpringContextUtil;
import jakarta.annotation.PostConstruct;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;

@Component
public class AccountRelationFactory {

    private static Map<Integer, AbstractAccountRelationService> services = new HashMap<>();

    @PostConstruct
    public void init() {
        this.registryService();
    }

    /**
     * 账号关系抽象服务注册
     *
     */
    private void registryService() {

        services.put(RoleCodeEnum.USER.getCode(), SpringContextUtil.getBean(User2UserAccountRelationService.class));
        services.put(RoleCodeEnum.ADMIN.getCode(), SpringContextUtil.getBean(User2UserAccountRelationService.class));
        services.put(RoleCodeEnum.ROBOT.getCode(), SpringContextUtil.getBean(User2RobotAccountRelationService.class));
        services.put(RoleCodeEnum.GROUP.getCode(), SpringContextUtil.getBean(User2GroupAccountRelationService.class));
        services.put(RoleCodeEnum.PUBLIC_ACCOUNT.getCode(), SpringContextUtil.getBean(User2OfficialAccountRelationService.class));
    }

    public static AbstractAccountRelationService getService(Integer roleCode) {
        AbstractAccountRelationService accountRelationService = services.get(roleCode);
        if (accountRelationService != null) {
            return accountRelationService;
        }
        throw new BusinessException("不支持的关系服务");
    }
}
